#
# spec file for package moditect
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           moditect
Version:        1.2.2
Release:        1.5
Summary:        Tooling for the Java Module System
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://github.com/%{name}/%{name}
Source0:        %{url}/archive/refs/tags/%{version}.Final.tar.gz
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  mvn(com.beust:jcommander)
BuildRequires:  mvn(com.github.javaparser:javaparser-core)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-shade-plugin)
BuildArch:      noarch

%description
The ModiTect project aims at providing productivity tools for working with the
Java module system ("Jigsaw").

Currently the following tasks are supported:
• Generating module-info.java descriptors for given artifacts (Maven
  dependencies or local JAR files)
• Adding module descriptors to your project's JAR as well as existing JAR files
  (dependencies)
• Creating module runtime images

Compared to authoring module descriptors by hand, using ModiTect saves you work
by defining dependence clauses based on your project's dependencies, describing
exported and opened packages with patterns (instead of listing all packages
separately), auto-detecting service usages and more. You also can use ModiTect
to add a module descriptor to your project JAR while staying on Java 8 with
your own build.

In future versions functionality may be added to work with other tools like
jmod etc. under Maven and other dependency management tools in a comfortable
manner.

%package javadoc
Summary:        API documentation for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.

%prep
%setup -q -n %{name}-%{version}.Final

%pom_remove_parent parent

%pom_xpath_inject pom:project '<groupId>org.moditect</groupId>' parent

%pom_remove_plugin com.mycila:license-maven-plugin parent

%pom_disable_module integrationtest

%pom_change_dep org.jcommander:jcommander com.beust: core

%build
%{mvn_build} -f -- \
	-Dproject.build.outputTimestamp=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ)

%install
%mvn_install
%fdupes %{buildroot}%{_javadocdir}/%{name}

%files -f .mfiles
%license LICENSE.txt
%doc README.md

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt

%changelog
* Wed Sep  4 2024 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.2.2
  * Changelog
    = 04bb13a Releasing version 1.2.2.Final
    = af42936 Only use inner class heuristic with class names
    = e06db30 Next version 1.3.0-SNAPSHOT
    = e070303 Releasing version 1.2.1.Final
- Update to v1.2.1
  * Changelog
    = 8c6acb9 Releasing version 1.2.1.Final
    = 774e118 #244 Use temporary working file when adding
    module-info
    = 80c1c1d Fix indentation to 4 spaces
    = 8dbf0f4 Fix missing character in licenses
    = 27c1bd6 remove parent path and packaging since their value
    was the default one
    = 24031e4 Update Hibernate validator to Jakarta EE 10
    compatibility and fix the build
    = cdbffd6 Update last files without right license
    = 77e196e includes reviewer remark on opening all the module:
    changed it to an exports directive
    = 7c19d07 Change in plugin configuration and order of declared
    modules to obtain a fonctionning jlink image
    = 9bc4156 Add --ignore-missing-deps to Vertx pom to prevent
    modules error from optional dependencies
    = 25ef0e4 Correct License text indentation
    = 87b5463 Update various dependencies and plugins version to
    last stable non-breaking version
    = 0e9c9c4 Update license
    = fd47eaa update embedded maven version to 3.9.6, version
    before 3.9.0 had cause starnge dependecies issues while
    resolving module-path
    = da10098 Next version 1.3.0-SNAPSHOT
    = 92841ed Releasing version 1.2.0.Final
- Update to v1.2.0
  * Changelog
    = 0f9da83 Releasing version 1.2.0.Final
    = 30fe752 Update project timestamp to git expression after
    release
    = e66d794 #95 Marking Maven plug-in goals with @threadsafe
    = e096f8e Update release configuration
    = a793af4 #216 create-runtime-image: Error message on missing
    artifact, closes #216
    = 4c39711 #213 Support additional values for compress when
    creating a runtime image, closes #123
    = 5d63f7b #222 Use ZipFile API to set timestamps, closes #222
    = be7d707 [#226] update to asm 9.6 for Java 22 support, closes
    [#226]
    = 7733129 [CHORE] update parent
    = 915bcec [#223] don't use directory plugin, closes #223
    = f32d851 Next version 1.2.0-SNAPSHOT
    = 8fa9fbb Releasing version 1.1.0
- Reproducible builds: use SOURCE_DATE_EPOCH for timestamp
* Sat Dec 23 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.1.0
  * Changelog
    = Tasks
    ~ 798baa0 Releasing version 1.1.0
    ~ a5640b5 Releasing version
    = Issues
    ~ b0ea885 #217 Configure JReleaser for deployments to Maven
    Central
    ~ 736e8a5 #203 Adding version to release commit message
    ~ 0f2e59d #190 Don't fail build on already modular JARs
    ~ 3e2b18e #185 Add outputTimestamp property for reproducible
    builds
    = Dependencies
    ~ d84c377 Bump jreleaser to 1.8.0
    ~ 238bdb7 Bump asm to 9.5
    ~~~
    ~ f3e629b set last access and create times
    ~ defcb8a Update release version in README
    ~ 322508f Fix integration test settings in undertow module
    ~ db9010a Reset reproducible timestamp expression
    ~ 2ef77d9 Next version 1.1.0-SNAPSHOT
    ~ 36eb1ac Simplify release workflow
    ~ 0c22f34 Push release to a branch due to branch protection
    rules
    ~ 7432c99 Apply formatting rules from ModiTect parent
    ~ 712c529 Update parent pom to make build reproducible
    ~ 8a29a60 Make AddModuleInfoMojo.jvmVersion non-readonly
    ~ a1bd562 Update readme with latest release
    ~ 5e4f1cc Next version 1.0.0-SNAPSHOT
* Mon May 22 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.0.0.Final
  * Changelog
    = Tasks
    ~ 41784cb Releasing version
    = Issues
    ~ 0f2e59d #190 Don't fail build on already modular JARs
    ~ 3e2b18e #185 Add outputTimestamp property for reproducible
    builds
    ~~~
    ~ 36eb1ac Simplify release workflow
    ~ 0c22f34 Push release to a branch due to branch protection
    rules
    ~ 7432c99 Apply formatting rules from ModiTect parent
    ~ 712c529 Update parent pom to make build reproducible
    ~ 8a29a60 Make AddModuleInfoMojo.jvmVersion non-readonly
    ~ a1bd562 Update readme with latest release
    ~ 5e4f1cc Next version 1.0.0-SNAPSHOT
* Sun Apr  2 2023 Anton Shvetz <shvetz.anton@gmail.com>
- Update to v1.0.0.RC3
  * Changelog
    = Tasks
    ~ 0bb9d54 Releasing version
    = Issues
    ~ #179 Check if a JAR is already modular before enhancing it
    ~ #169 Document changes applied by #170 (#181)
    ~ #169 Add support for dependency exclusion
    ~ #151: Use project.build.fileName to resolve default JAR
    (#180)
    ~ #154 Update version to snapshot upon release
    ~ #162 Avoid fragile Java version parsing when looking for
    module-info.java
    = Dependencies
    ~ Bump slfj4 to 1.7.36
    ~ Bump jcommander to 1.82
    ~ Bump plexus to 3.5.0
    ~ Bump maven-plugin-annotations to 3.8.1
    ~ Bump several plugins defined by moditect-parent
    ~ Bump build-helper-maven-plugin to 3.3.0
    ~ Bump maven-shade-plugin to 3.4.1
    ~ Bump maven-plugin-plugin to 3.8.1
    ~ Bump maven wrapper to 3.1.1 and maven to 3.8.7
    ~ Bump compile-testing to 0.21.0
    ~ Bump assertj to 3.24.2
    ~ Bump java-parser to 3.25.1
    ~ Bump hibernate-validator in
    /integrationtest/hibernate-validator
    ~~~
    ~ Version bumps must be done with -pl :moditect-parent
    ~ Default branch was renamed to main
    ~ Update missing license header
    ~ Update license headers
    ~ Update GitHub workflow configuration
    ~ Upgrade release configuration
    ~ Update README.md
    ~ Typos
    ~ Fix code formatting
    ~ Add LogWriter to print JDeps output to log
    ~ Avoid error in logs when passing "--multi-release base" to
    jdeps
* Mon Dec 12 2022 Anton Shvetz <shvetz.anton@gmail.com>
- Initial packaging with v1.0.0.RC2
